/**
 * Copyright (c) 2000-2013 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package it.tref.liferay.mapit.map.service.persistence;

import com.liferay.portal.service.persistence.BasePersistence;

import it.tref.liferay.mapit.map.model.Plugin;

/**
 * The persistence interface for the plugin service.
 *
 * <p>
 * Caching information and settings can be found in <code>portal.properties</code>
 * </p>
 *
 * @author
 * @see PluginPersistenceImpl
 * @see PluginUtil
 * @generated
 */
public interface PluginPersistence extends BasePersistence<Plugin> {
	/*
	 * NOTE FOR DEVELOPERS:
	 *
	 * Never modify or reference this interface directly. Always use {@link PluginUtil} to access the plugin persistence. Modify <code>service.xml</code> and rerun ServiceBuilder to regenerate this interface.
	 */

	/**
	* Returns the plugin where context = &#63; or throws a {@link it.tref.liferay.mapit.map.NoSuchPluginException} if it could not be found.
	*
	* @param context the context
	* @return the matching plugin
	* @throws it.tref.liferay.mapit.map.NoSuchPluginException if a matching plugin could not be found
	* @throws SystemException if a system exception occurred
	*/
	public it.tref.liferay.mapit.map.model.Plugin findByContext(
		java.lang.String context)
		throws com.liferay.portal.kernel.exception.SystemException,
			it.tref.liferay.mapit.map.NoSuchPluginException;

	/**
	* Returns the plugin where context = &#63; or returns <code>null</code> if it could not be found. Uses the finder cache.
	*
	* @param context the context
	* @return the matching plugin, or <code>null</code> if a matching plugin could not be found
	* @throws SystemException if a system exception occurred
	*/
	public it.tref.liferay.mapit.map.model.Plugin fetchByContext(
		java.lang.String context)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns the plugin where context = &#63; or returns <code>null</code> if it could not be found, optionally using the finder cache.
	*
	* @param context the context
	* @param retrieveFromCache whether to use the finder cache
	* @return the matching plugin, or <code>null</code> if a matching plugin could not be found
	* @throws SystemException if a system exception occurred
	*/
	public it.tref.liferay.mapit.map.model.Plugin fetchByContext(
		java.lang.String context, boolean retrieveFromCache)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Removes the plugin where context = &#63; from the database.
	*
	* @param context the context
	* @return the plugin that was removed
	* @throws SystemException if a system exception occurred
	*/
	public it.tref.liferay.mapit.map.model.Plugin removeByContext(
		java.lang.String context)
		throws com.liferay.portal.kernel.exception.SystemException,
			it.tref.liferay.mapit.map.NoSuchPluginException;

	/**
	* Returns the number of plugins where context = &#63;.
	*
	* @param context the context
	* @return the number of matching plugins
	* @throws SystemException if a system exception occurred
	*/
	public int countByContext(java.lang.String context)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns all the plugins where active = &#63;.
	*
	* @param active the active
	* @return the matching plugins
	* @throws SystemException if a system exception occurred
	*/
	public java.util.List<it.tref.liferay.mapit.map.model.Plugin> findByActive(
		boolean active)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns a range of all the plugins where active = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link it.tref.liferay.mapit.map.model.impl.PluginModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param active the active
	* @param start the lower bound of the range of plugins
	* @param end the upper bound of the range of plugins (not inclusive)
	* @return the range of matching plugins
	* @throws SystemException if a system exception occurred
	*/
	public java.util.List<it.tref.liferay.mapit.map.model.Plugin> findByActive(
		boolean active, int start, int end)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns an ordered range of all the plugins where active = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link it.tref.liferay.mapit.map.model.impl.PluginModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param active the active
	* @param start the lower bound of the range of plugins
	* @param end the upper bound of the range of plugins (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @return the ordered range of matching plugins
	* @throws SystemException if a system exception occurred
	*/
	public java.util.List<it.tref.liferay.mapit.map.model.Plugin> findByActive(
		boolean active, int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns the first plugin in the ordered set where active = &#63;.
	*
	* @param active the active
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching plugin
	* @throws it.tref.liferay.mapit.map.NoSuchPluginException if a matching plugin could not be found
	* @throws SystemException if a system exception occurred
	*/
	public it.tref.liferay.mapit.map.model.Plugin findByActive_First(
		boolean active,
		com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
		throws com.liferay.portal.kernel.exception.SystemException,
			it.tref.liferay.mapit.map.NoSuchPluginException;

	/**
	* Returns the first plugin in the ordered set where active = &#63;.
	*
	* @param active the active
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching plugin, or <code>null</code> if a matching plugin could not be found
	* @throws SystemException if a system exception occurred
	*/
	public it.tref.liferay.mapit.map.model.Plugin fetchByActive_First(
		boolean active,
		com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns the last plugin in the ordered set where active = &#63;.
	*
	* @param active the active
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching plugin
	* @throws it.tref.liferay.mapit.map.NoSuchPluginException if a matching plugin could not be found
	* @throws SystemException if a system exception occurred
	*/
	public it.tref.liferay.mapit.map.model.Plugin findByActive_Last(
		boolean active,
		com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
		throws com.liferay.portal.kernel.exception.SystemException,
			it.tref.liferay.mapit.map.NoSuchPluginException;

	/**
	* Returns the last plugin in the ordered set where active = &#63;.
	*
	* @param active the active
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching plugin, or <code>null</code> if a matching plugin could not be found
	* @throws SystemException if a system exception occurred
	*/
	public it.tref.liferay.mapit.map.model.Plugin fetchByActive_Last(
		boolean active,
		com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns the plugins before and after the current plugin in the ordered set where active = &#63;.
	*
	* @param pluginId the primary key of the current plugin
	* @param active the active
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the previous, current, and next plugin
	* @throws it.tref.liferay.mapit.map.NoSuchPluginException if a plugin with the primary key could not be found
	* @throws SystemException if a system exception occurred
	*/
	public it.tref.liferay.mapit.map.model.Plugin[] findByActive_PrevAndNext(
		long pluginId, boolean active,
		com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
		throws com.liferay.portal.kernel.exception.SystemException,
			it.tref.liferay.mapit.map.NoSuchPluginException;

	/**
	* Removes all the plugins where active = &#63; from the database.
	*
	* @param active the active
	* @throws SystemException if a system exception occurred
	*/
	public void removeByActive(boolean active)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns the number of plugins where active = &#63;.
	*
	* @param active the active
	* @return the number of matching plugins
	* @throws SystemException if a system exception occurred
	*/
	public int countByActive(boolean active)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Caches the plugin in the entity cache if it is enabled.
	*
	* @param plugin the plugin
	*/
	public void cacheResult(it.tref.liferay.mapit.map.model.Plugin plugin);

	/**
	* Caches the plugins in the entity cache if it is enabled.
	*
	* @param plugins the plugins
	*/
	public void cacheResult(
		java.util.List<it.tref.liferay.mapit.map.model.Plugin> plugins);

	/**
	* Creates a new plugin with the primary key. Does not add the plugin to the database.
	*
	* @param pluginId the primary key for the new plugin
	* @return the new plugin
	*/
	public it.tref.liferay.mapit.map.model.Plugin create(long pluginId);

	/**
	* Removes the plugin with the primary key from the database. Also notifies the appropriate model listeners.
	*
	* @param pluginId the primary key of the plugin
	* @return the plugin that was removed
	* @throws it.tref.liferay.mapit.map.NoSuchPluginException if a plugin with the primary key could not be found
	* @throws SystemException if a system exception occurred
	*/
	public it.tref.liferay.mapit.map.model.Plugin remove(long pluginId)
		throws com.liferay.portal.kernel.exception.SystemException,
			it.tref.liferay.mapit.map.NoSuchPluginException;

	public it.tref.liferay.mapit.map.model.Plugin updateImpl(
		it.tref.liferay.mapit.map.model.Plugin plugin)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns the plugin with the primary key or throws a {@link it.tref.liferay.mapit.map.NoSuchPluginException} if it could not be found.
	*
	* @param pluginId the primary key of the plugin
	* @return the plugin
	* @throws it.tref.liferay.mapit.map.NoSuchPluginException if a plugin with the primary key could not be found
	* @throws SystemException if a system exception occurred
	*/
	public it.tref.liferay.mapit.map.model.Plugin findByPrimaryKey(
		long pluginId)
		throws com.liferay.portal.kernel.exception.SystemException,
			it.tref.liferay.mapit.map.NoSuchPluginException;

	/**
	* Returns the plugin with the primary key or returns <code>null</code> if it could not be found.
	*
	* @param pluginId the primary key of the plugin
	* @return the plugin, or <code>null</code> if a plugin with the primary key could not be found
	* @throws SystemException if a system exception occurred
	*/
	public it.tref.liferay.mapit.map.model.Plugin fetchByPrimaryKey(
		long pluginId)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns all the plugins.
	*
	* @return the plugins
	* @throws SystemException if a system exception occurred
	*/
	public java.util.List<it.tref.liferay.mapit.map.model.Plugin> findAll()
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns a range of all the plugins.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link it.tref.liferay.mapit.map.model.impl.PluginModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param start the lower bound of the range of plugins
	* @param end the upper bound of the range of plugins (not inclusive)
	* @return the range of plugins
	* @throws SystemException if a system exception occurred
	*/
	public java.util.List<it.tref.liferay.mapit.map.model.Plugin> findAll(
		int start, int end)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns an ordered range of all the plugins.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link it.tref.liferay.mapit.map.model.impl.PluginModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param start the lower bound of the range of plugins
	* @param end the upper bound of the range of plugins (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @return the ordered range of plugins
	* @throws SystemException if a system exception occurred
	*/
	public java.util.List<it.tref.liferay.mapit.map.model.Plugin> findAll(
		int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Removes all the plugins from the database.
	*
	* @throws SystemException if a system exception occurred
	*/
	public void removeAll()
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns the number of plugins.
	*
	* @return the number of plugins
	* @throws SystemException if a system exception occurred
	*/
	public int countAll()
		throws com.liferay.portal.kernel.exception.SystemException;
}